#
# spec file for package libosmo-abis
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define version_unconverted 0.8.1

Name:           libosmo-abis
Version:        0.8.1
Release:        bp153.1.20
Summary:        Osmocom library for A-bis interface between BTS and BSC
License:        AGPL-3.0-or-later AND GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://osmocom.org/projects/libosmo-abis/wiki/Libosmo-abis

Source:         %name-%version.tar.xz
Patch1:         osmo-talloc.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  automake >= 1.6
#BuildRequires:  dahdi-linux-devel
BuildRequires:  libtool >= 2
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  xz
BuildRequires:  pkgconfig(libosmocore) >= 1.0.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.0.0
BuildRequires:  pkgconfig(libosmovty) >= 1.0.0
BuildRequires:  pkgconfig(ortp) >= 0.22
BuildRequires:  pkgconfig(talloc)

%description
In GSM, A-bis is a BSS-internal interface link between the BTS and
BSC. This interface allows control of the radio equipment and radio
frequency allocation in the BTS.

%package -n libosmoabis6
Summary:        Osmocom GSM A-bis interface library
License:        AGPL-3.0-or-later
Group:          System/Libraries

%description -n libosmoabis6
In the GSM system architecture, A-bis is a Base Station
System-internal interface linking the Base Transceiver Stations (BTS)
and Base Station Controller (BSC). This interface allows control of
the radio equipment and radio frequency allocation in the BTS.

This library contains common/shared code regarding this A-bis
interface. It also implements drivers for mISDN and DAHDI-based E1
cards, as well as some A-bis/IP dialects.

%package -n libosmoabis-devel
Summary:        Development files for the Osmocom GSM A-bis library
License:        AGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmoabis6 = %version
Requires:       libosmocore-devel >= 1.0.0
Requires:       libosmogsm-devel >= 1.0.0

%description -n libosmoabis-devel
This library contains common/shared code regarding the GSM A-bis
interface. It also implements drivers for mISDN and DAHDI-based E1
cards, as well as some A-bis/IP dialects.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmoabis.

%package -n libosmotrau2
Summary:        Osmocom GSM TRAU (E1/RTP) library
License:        GPL-2.0-or-later
Group:          System/Libraries

%description -n libosmotrau2
This library implements the Transcoder and Rate Adaptation Unit (TRAU) for
GSM systems.
The TRAU enables the use of lower rates (32, 16 or 8 kbps) over the
A-bis interface instead of the 64 kbps ISDN rate for which the Mobile
Switching Center (MSC) is designed.

%package -n libosmotrau-devel
Summary:        Development files for the Osmocom TRAU (E1/RTP) library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libosmotrau2 = %version

%description -n libosmotrau-devel
This library implements the Transcoder and Rate Adaptation Unit
(TRAU) for GSM systems.

This subpackage contains libraries and header files for developing
applications that want to make use of libosmotrau.

%prep
%setup -q
%patch -P 1 -p1

%build
echo "%version" >.tarball-version
autoreconf -fiv
%configure \
    --enable-shared \
    --disable-static \
    --disable-dahdi \
    --includedir="%_includedir/%name"
make %{?_smp_mflags}

%install
b="%buildroot"
make %{?_smp_mflags} install DESTDIR="$b"
find "$b/%_libdir" -type f -name "*.la" -delete

%check
if ! make %{?_smp_mflags} check; then
	find . -name testsuite.log -exec cat "{}" "+"
%ifarch %ix86 x86_64
	exit 1
%endif
fi

%post   -n libosmoabis6 -p /sbin/ldconfig
%postun -n libosmoabis6 -p /sbin/ldconfig
%post   -n libosmotrau2 -p /sbin/ldconfig
%postun -n libosmotrau2 -p /sbin/ldconfig

%files -n libosmoabis6
%defattr(-,root,root)
%_libdir/libosmoabis.so.6*

%files -n libosmoabis-devel
%defattr(-,root,root)
%doc COPYING
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/abis/
%_libdir/libosmoabis.so
%_libdir/pkgconfig/libosmoabis.pc

%files -n libosmotrau2
%defattr(-,root,root)
%_libdir/libosmotrau.so.2*

%files -n libosmotrau-devel
%defattr(-,root,root)
%doc COPYING
%dir %_includedir/%name
%dir %_includedir/%name/osmocom
%_includedir/%name/osmocom/trau
%_libdir/libosmotrau.so
%_libdir/pkgconfig/libosmotrau.pc

%changelog
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.8.1
  * ortp: disable SO_REUSEADDR + SO_REUSEPORT
  * Add rtp_test to show the double-bind bug of OS#4444
- Update patch:
  * osmo-talloc.diff
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 0.8.0
  * input/ipa_keepalive.c: make sure IPA keepalive FSM is registered
  * input/ipaccess.c: propagate errors from ipa_parse_unitid()
  * ipa: Allow setting local addr and port for struct ipa_client_conn
  * ipa: ipa_server_link_close() add checks of link state
* Thu Aug 15 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.7.0
  * ipaccess: allow TCP keepalive for IPA clients
  * Add IPA keep-alive FSM implementation
* Mon Jan 28 2019 mardnh@gmx.de
- Update to new upstream release 0.6.0
  * Bugfix release only.
    The full changelog is available via
    http://git.osmocom.org/libosmo-abis/plain/debian/changelog?h=0.6.0
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 0.5.1
  * unixsocket: fix a potential string overflow
  * fix double-free/use-after-free of pointers in struct e1inp_line
  * ortp: reset RTP session on SSRC changes
  * ortp: detect SSRC changes immediately
  * e1_input: Replace '.' in counter names with ':'
* Sun Mar 25 2018 jengelh@inai.de
- Show testsuite.log when tests are failing.
* Mon Oct  2 2017 jengelh@inai.de
- Update to new upstream snapshot 0.4.0.2
  * osmo_ortp: Duration of a RTP frame affects timestamp of the
    next one
  * osmo_ortp: Add osmo_rtp_drop_frame API
  * osmo_ortp: Fix warning: check ortp API in
    rtp_session_signal_connect
- Drop 0001-build-resolve-compiler-warnings.patch (merged)
* Fri Apr 28 2017 jengelh@inai.de
- Update to new upstream snapshot 0.3.2.68
  * Really fix order of set_connected_mode and set_remote_addr
  * Resync RTP session in case of timestamp jump
  * e1_input: Add E1 timeslot number to input_signal_data
  * Convert e1inp_{sign,ts}type_name() to use struct value_string
  * Implement new 'raw' input type for E1 timeslots
  * Add HDLC timeslot mode
  * lapd: adding support for ericsson's lapd dialect
  * Enable adaptive jitter compensation
  * lapd: Reduce N200 (SABM retransmission count)
- Drop ortp27.diff (no longer needed)
* Sat Oct  1 2016 jengelh@inai.de
- Update to new upstream snapshot 0.3.2.24
  * No visible changes
- Add ortp27.diff
* Sat Jul 30 2016 jengelh@inai.de
- Update to new upstream snapshot 0.3.2.19
  * ipa driver: make bind address vty configurable
  * Do not send RTP to port 0
  * Add defines for FN to SAMPLE conversion
* Fri Jan 22 2016 jengelh@inai.de
- Move to seprate location and ensure pkgconfig is used correctly
* Wed Dec 23 2015 jengelh@inai.de
- Update to new upstream release 0.3.2.3
  * ortp: Guard the jitter stats with a version check
  * ortp: Export statistics for the bts or similar
  * export lapd_tei_alloc for libosmo-netif
* Thu Apr  2 2015 jengelh@inai.de
- Add 0001-build-resolve-compiler-warnings.patch
* Sun Mar  1 2015 jengelh@inai.de
- Update to new upstream release 0.3.1
  * No changelog was provided, again
* Thu Oct  2 2014 jengelh@inai.de
- Update to new upstream release 0.3.0
  * No changelog was provided
* Mon Jul 21 2014 jengelh@inai.de
- Update to new upstream release 0.2.0
  * No changelog was provided
- Remove 0001-lapd-Do-not-override-t203_sec-initialization.patch,
  0002-misdn-Set-ret-to-0-when-using-the-LAPD-from-userspac.patch
  (no longer needed)
* Sun Jun  2 2013 jengelh@inai.de
- Add 0001-lapd-Do-not-override-t203_sec-initialization.patch,
  0002-misdn-Set-ret-to-0-when-using-the-LAPD-from-userspac.patch
* Fri Feb 22 2013 jengelh@inai.de
- Initial package (version 0.1.5) for build.opensuse.org
